@@ -10,7 +10,7 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.78'; # VERSION
+our $VERSION = '1.79'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -129,6 +129,7 @@ sub configure
         'repository.url'  => sprintf("git://github.com/%s/%s.git",      $user, $repo),
         'repository.web'  => sprintf("https://github.com/%s/%s",        $user, $repo),
         'repository.type' => 'git',
+        maybe 'x_IRC' => $self->payload->{irc},
       },
     ]);
   };
@@ -241,7 +242,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.78
+version 1.79
 
 =head1 SYNOPSIS
 
@@ -440,6 +441,11 @@ to install L<Dist::Zilla> and L<Dist::Zilla::PluginBundle::Author::Plicease>.
 
 Additional dirty allowed file passed to @Git.
 
+=head2 irc
+
+IRC discussion URL for x_IRC meta (maybe changed to non x_ meta if/when IRC
+becomes formally supported).
+
 =head1 SEE ALSO
 
 =over 4
